@@ -53,6 +53,7 @@ Game::Game(PlayerSettings* playerSettings)
     m_soundDie = new KgSound(KStandardDirs::locate("appdata", "sounds/die.wav"));
     
     m_arena = 0;
+    m_randomArenaModeArenaList.clear();
     m_gameScene = 0;
     m_winPoints = Settings::self()->pointsToWin();
     
@@ -80,7 +81,7 @@ Game::Game(PlayerSettings* playerSettings)
 }
 
 void Game::init()
-{
+{    
     // Create the Arena instance
     m_arena = new Arena();
 
@@ -94,41 +95,44 @@ void Game::init()
     QString filePath;
     if(Settings::self()->randomArenaMode())
     {
-        QStringList arenasAvailable;
-        QStringList randomArenaModeArenaList = Settings::self()->randomArenaModeArenaList();
-        
-        KGlobal::dirs()->addResourceType("arenaselector", "data", KGlobal::mainComponent().componentName() + "/arenas/");
-        KGlobal::dirs()->findAllResources("arenaselector", "*.desktop", KStandardDirs::Recursive, arenasAvailable);
-        
-        QStringList::Iterator i = randomArenaModeArenaList.begin();
-        while(i != randomArenaModeArenaList.end())
+        if(m_randomArenaModeArenaList.isEmpty())
         {
-            if(arenasAvailable.contains(*i))
+            QStringList arenasAvailable;
+            m_randomArenaModeArenaList = Settings::self()->randomArenaModeArenaList();
+
+            KGlobal::dirs()->addResourceType("arenaselector", "data", KGlobal::mainComponent().componentName() + "/arenas/");
+            KGlobal::dirs()->findAllResources("arenaselector", "*.desktop", KStandardDirs::Recursive, arenasAvailable);
+
+            QStringList::Iterator i = m_randomArenaModeArenaList.begin();
+            while(i != m_randomArenaModeArenaList.end())
             {
-                i++;
+                if(arenasAvailable.contains(*i))
+                {
+                    i++;
+                }
+                else
+                {
+                    i = m_randomArenaModeArenaList.erase(i);
+                }
             }
-            else
+
+            if(m_randomArenaModeArenaList.isEmpty())
             {
-                i = randomArenaModeArenaList.erase(i);
+                m_randomArenaModeArenaList = arenasAvailable;
             }
         }
         
-        if(randomArenaModeArenaList.isEmpty())
-        {
-            randomArenaModeArenaList = arenasAvailable;
-        }
-        
-        qsrand(QDateTime::currentDateTime().toTime_t());
-        int nIndex = ((double) qrand() / RAND_MAX) * randomArenaModeArenaList.count();
+        int nIndex = ((double) qrand() / RAND_MAX) * m_randomArenaModeArenaList.count();
         if(nIndex < 0)
         {
             nIndex = 0;
         }
-        else if(nIndex >= randomArenaModeArenaList.count())
+        else if(nIndex >= m_randomArenaModeArenaList.count())
         {
-            nIndex = randomArenaModeArenaList.count() - 1;
+            nIndex = m_randomArenaModeArenaList.count() - 1;
         }
-        filePath = KStandardDirs::locate("appdata", "arenas/" + randomArenaModeArenaList.at(nIndex));
+        filePath = KStandardDirs::locate("appdata", "arenas/" + m_randomArenaModeArenaList.at(nIndex));
+        m_randomArenaModeArenaList.removeAt(nIndex);
     }
     else
     {
@@ -332,7 +336,6 @@ QList<Bonus*> Game::getBonus() const
 void Game::createBonus()
 {
     Bonus* bonus;
-    qsrand(QDateTime::currentDateTime().toTime_t());
     int nBonusCount = 0.3 * m_blocks.size();
     int nBadBonusCount = 0.1 * m_blocks.size();
     int nNeutralBonusCount = static_cast <int> ((qrand()/1.0)/RAND_MAX * 2);
@@ -561,7 +564,7 @@ void Game::decrementRemainingRoundTime()
                 nRow = m_arena->getNbRows() * (qrand()/1.0)/RAND_MAX;
                 nCol = m_arena->getNbColumns() * (qrand()/1.0)/RAND_MAX;
                 cellType = m_arena->getCell(nRow, nCol).getType();
-                if(cellType != Granatier::Cell::WALL && cellType != Granatier::Cell::HOLE && cellType != Granatier::Cell::BLOCK)
+                if(cellType != Granatier::Cell::WALL && cellType != Granatier::Cell::HOLE && m_arena->getCell(nRow, nCol).isWalkable(0))
                 {
                     bFound = true;
                 }
@@ -570,7 +573,7 @@ void Game::decrementRemainingRoundTime()
             
             m_bombCount++;
             Bomb* bomb = new Bomb((nCol + 0.5) * Granatier::CellSize, (nRow + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 1000);    // time in ms
-            bomb->setBombPower(1);
+            bomb->setBombPower((qrand()/1.0)/RAND_MAX * 2 + 1);
             emit bombCreated(bomb);
             connect(bomb, SIGNAL(bombDetonated(Bomb*)), this, SLOT(bombDetonated()));
             m_bombs.append(bomb);
@@ -578,7 +581,7 @@ void Game::decrementRemainingRoundTime()
             {
                 m_roundTimer->setInterval(m_roundTimer->interval() + m_remainingTime);
             }
-            else if (m_roundTimer->interval() > 40)
+            else if (m_roundTimer->interval() > 30)
             {
                 m_roundTimer->setInterval(m_roundTimer->interval() - 1);
             }
