@@ -28,7 +28,7 @@
 using namespace std;
 
 static const char description[] = I18N_NOOP("KDE Bounce Ball Game");
-static const char version[] = "0.10";
+static const char version[] = "0.11";
 static const char copyleft[] = I18N_NOOP("(c) 2000-2005, Stefan Schimanski\n(c) 2007, Tomasz Boczkowski");
 
 int main(int argc, char **argv)
@@ -47,7 +47,7 @@ int main(int argc, char **argv)
   KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication application;
-  KGlobal::locale()->insertCatalog("libkdegames");
+  KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
 
   if (application.isSessionRestored())
       RESTORE(KBounceMainWindow)
